@tailwind base;
@tailwind components;
@tailwind utilities;

:root {
  --lk-va-bar-width: 72px;
  --lk-control-bar-height: unset;
}

.agent-visualizer > .lk-audio-bar {
  width: 72px;
}

.lk-agent-control-bar {
  @apply border-t-0 p-0 h-min mr-4;
}

.lk-disconnect-button {
  @apply h-[36px] hover:bg-[#6b221a] hover:text-[white] bg-[#31100c] border-[#6b221a];
}
